
#delimit;
clear;
set mem 200m;
cd "[INSERT DATA DIRECTORY]";
use centralrole1;

** RECODES;

* URBAN AND LARGER SCHOOLS INDICATORS;

generate big=1 if ncas88>=15 & rural88==0;
replace  big=0 if ncas88< 15 | rural88==1;

generate big90=1 if ncas90>=15 & rural88==0;
replace  big90=0 if ncas90< 15 | rural88==1;

generate urban88=rural88;
recode   urban88 0=1 1=0;

* 1988 AVERAGE SCORE;

generate x88=(cas88+mat88)/2;

* FIRST DEFINITION OF DISCONTINUITY (see text);

egen     temp1=max(x88), by(rgn88 p90);
replace  temp1=. if p90==0 | p90==.;
egen     temp2=max(temp1), by(rgn88);
generate temp3=int(temp2)+1;
rename temp3 integer;
gen rule1=x88-integer;
gen correct1=0;
replace correct1=1 if (rule1<=0 & p90==1) | (rule1>=0 & p90==0);
drop temp1 temp2;

* SECOND DEFINITION OF DISCONTINUITY (see text);

egen    temp4=pctile(x88), p(95) by(rgn88 p90);
replace temp4=. if p90==0 | p90==.;
egen    temp5=max(temp4), by(rgn88);
gen temp6=int(temp5)+1;
rename temp6 integer2;
gen rule2=x88-integer2+0.6;
gen correct2=0;
replace correct2=1 if (rule2<=0 & p90==1) | (rule2>=0 & p90==0);
drop temp4 temp5;

* ENROLLMENTS;

gen w8890=(ncas88+ncas90)/2;
gen w8892=(ncas88+ncas92)/2;

* GAIN SCORES;

gen dcas90=cas90-cas88;
gen dcas92=cas92-cas88;
gen dmat90=mat90-mat88;
gen dmat92=mat92-mat88;

egen temp=rmiss(mat88 cas88 mat90 cas90 dmat90 dcas90 p90 urban88 ncas88 ncas90 indice90);
egen temp2=rmiss(mat88 cas88 mat92 cas92 dmat92 dcas92 p90 urban88 ncas88 ncas92 indice90 indice92);

** FIGURE 1;

* Note: Figure 1 is not based upon Chile data;

** FIGURE 2;

* Panel A;

ksm cas88 ncas88, bw(.1) line gen(cas88bw1) nograph;

scatter cas88 cas88bw1 ncas88,
      msymbol(p i)
	mcolor(black green)
	c(. l)
	clcolor(black green)
  	sort
	legend(off)
	xlabel(0 50 100 150 200 250 300 350)
	ylabel(0(20)100,format(%9.0fc))
	title(Panel A, position(11) size(medium))
	ytitle(1988 language score)
	xtitle(1988 enrollment)
	scheme(s1color)
	saving(fig2a.gph,replace);

* Panel B;

replace w8890=ncas88+ncas90;
gen n8890=(ncas88+ncas90)/(ncas88*ncas90);
ksm dcas90 ncas88, bwidth(0.10) gen(b) nograph;

gen ci99=5.002457 + invnorm(0.99)*sqrt(29.38505 + 586.4824*n8890);
gen ci01=5.002457 - invnorm(0.99)*sqrt(29.38505 + 586.4824*n8890);

scatter dcas90 ci99 ci01 w8890,
	msymbol(p i i)
	mcolor(black green green)
	connect(. l l) sort
	clcolor(black green green)
	legend(off)
	xlabel(0 100 200 300 400 500 600 700)
	ylabel(-60(20)60)
	title(Panel B, position(11) size(medium))
	ytitle(1988-90 language gain score )
	xtitle("Total enrollment, 1988 and 1990")
	scheme(s1color)
	saving(fig2b.gph,replace);

* Panel C;

ksm ncas88 x88, line bw(.1) gen(ncas88bw1) nograph;

scatter ncas88bw1 x88,
	msymbol(p)
	mcolor(black)
	connect(l)
	clcolor(black)
	sort
	legend(off)
	xlabel(10(10)90)
	ylab(0(10)70)
	title(Panel C, position(11) size(medium))
	ytitle(1988 enrollment)
	xtitle("1988 average score")
	scheme(s1color)
	saving(fig2c.gph,replace);

* Panel D;

ksm dcas90 x88, bw(.1) line  gen(dcas90bw1);

scatter dcas90bw1 x88,
	msymbol(p)
	mcolor(black) 
	connect(l)
	clcolor(black)
	sort
	legend(off)
	xlabel(10(10)90)
	ylab(-20(10)20)
	title(Panel D, position(11) size(medium))
	ytitle(1988-90 language gain score)
	xtitle("1988 average score")
	scheme(s1color)
	saving(fig2d.gph,replace);

graph combine fig2a.gph fig2b.gph fig2c.gph fig2d.gph,
      scheme(s1color)
	saving(fig2,replace);

** FIGURE 3;

* Panel A;

scatter p90 x88 if rgn88==9 & temp==0,
	ms(oh)
	mcolor(black)	
	xlab(20 30 40 50 56 70 80 90)
	ylab(0(0.2)1,format(%9.1f))
	ytitle(P-900 status)
	xtitle(1988 average score)
	title(Panel A: Region 9 (all schools), position(11) size(medium))
	scheme(s1color)
	xline(56)
	saving(fig3a.gph,replace);

* Panel B;

scatter p90 x88 if rgn88==9 & big==1 & temp==0,
	ms(oh)	
	mcolor(black)	
	xlab(20 30 40 47.4 60 70 80 90)
	ylab(0(0.2)1,format(%9.1f))
	ytitle(P-900 status)
	xtitle(1988 average score)
	title(Panel B: Region 9 (urban, larger), position(11) size(medium))
	scheme(s1color)
	xline(47.4)
	saving(fig3b.gph,replace);

* Panel C;

gen ivrule2=0 if rule2>0 ;
replace ivrule2=1 if rule2<=0;

ksm p90 rule2 if big==1 & temp==0, bw(.05) gen(p90bw05) nograph;
reg p90 ivrule2 if big==1 & temp==0, robust;
predict p90hat if big==1 & p90~=. & temp==0;

scatter p90bw05 p90hat rule2 if big==1 & temp==0,
	ms(i i)
	mcolor(black black)
	c(l l)
	clpattern(l -)
	clcolor(black black)
	sort
	legend(off)	
	xlab(-20(10)40)
	ylab(0(0.2)1,format(%9.1f))
	ytitle(P-900 status)
	xtitle(1988 average score relative to cutoff)
	title("Panel C: Regions 1-13 (urban, larger)", position(11) size(medium))
	scheme(s1color)
	xline(0)
	saving(fig3c.gph,replace);

* Panel D;

ksm p90 rule2 if big==1 & rgn88~=13 & temp==0, bw(.05) gen(p90bw05_13) nograph;

reg p90 ivrule2 if big==1 & rgn88~=13 & temp==0, robust;
predict p90hat_13 if big==1 & rgn88~=13 & p90~=. & temp==0;

scatter p90bw05_13 p90hat_13 rule2 if big==1 & rgn88~=13 & temp==0,
	ms(i i)
	mcolor(black black)
	c(l l)
	clpattern(l -)
	clcolor(black black)
	sort
	legend(off)	
	xlab(-20(10)40)
	ylab(0(0.2)1,format(%9.1f))
	ytitle(P-900 status)
	xtitle(1988 average score relative to cutoff)
	title("Panel D: Regions 1-12 (urban, larger)", position(11) size(medium))
	scheme(s1color)
	xline(0)
	saving(fig3d.gph,replace);

graph combine fig3a.gph fig3b.gph fig3c.gph fig3d.gph,
      scheme(s1color)
	saving(fig3,replace);

** FIGURE 4;

* See below;

** FIGURE 5;

* Panel A;

drop p90hat;

ksm dmat90 rule2 if big==1 & p90==1 & temp==0, bw(.3) gen(p90hat) nograph;
ksm dmat90 rule2 if big==1 & p90==0 & temp==0, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp==0,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	ylab(-2(2)14)
	xlab(-20(10)40)
	legend(off)
	title(Panel A: 1988-90 math gain score, position(11) size(medium))
	ytitle(1988-90 math gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5a.gph,replace);
drop p90hat nonp90hat;

* Panel B;

ksm dcas90 rule2 if big==1 & p90==1 & temp==0, bw(.3) gen(p90hat)  nograph;
ksm dcas90 rule2 if big==1 & p90==0 & temp==0, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp==0,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	legend(off)
	ylab(-2(2)14)
	xlabel(-20(10)40)
	title(Panel B: 1988-90 lang. gain score, position(11) size(medium))
	ytitle(1988-90 lang. gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5b.gph,replace);
drop p90hat nonp90hat;

* Panel C;

ksm dmat92 rule2 if big==1 & p90==1 & temp2==0, bw(.3) gen(p90hat)  nograph;
ksm dmat92 rule2 if big==1 & p90==0 & temp2==0, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp2==0,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	legend(off)
	ylab(4(2)20)
	xlabel(-20(10)40)
	title(Panel C: 1988-92 math gain score, position(11) size(medium))
	ytitle(1988-92 math gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5c.gph,replace);
drop p90hat nonp90hat;

* Panel D;

ksm dcas92 rule2 if big==1 & p90==1 & temp2==0, bw(.3) gen(p90hat)   nograph;
ksm dcas92 rule2 if big==1 & p90==0 & temp2==0, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp2==0,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	legend(off)
	xlabel(-20(10)40)
	ylab(4(2)20)
	title(Panel D: 1988-92 lang. gain score, position(11) size(medium))
	ytitle(1988-92 lang. gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5d.gph,replace);
drop p90hat nonp90hat;

* Panel E;

ksm dmat92 rule2 if big==1 & p90==1 & temp2==0 & rgn88~=13, bw(.3) gen(p90hat)  nograph;
ksm dmat92 rule2 if big==1 & p90==0 & temp2==0 & rgn88~=13, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp2==0  & rgn88~=13,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	legend(off)
	ylab(4(2)20)
	xlabel(-20(10)40)
	title("Panel E: 1988-92 math (Regions 1-12)", position(11) size(medium))
	ytitle(1988-92 math gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5e.gph,replace);
drop p90hat nonp90hat;

* Panel F;

ksm dcas92 rule2 if big==1 & p90==1 & temp2==0 & rgn88~=13, bw(.3) gen(p90hat)   nograph;
ksm dcas92 rule2 if big==1 & p90==0 & temp2==0 & rgn88~=13, bw(.1) gen(nonp90hat)  nograph;

scatter p90hat nonp90hat rule2 if big==1 & (p90==1 & rule2<10) | (p90==0 & rule2>-10) & temp2==0 & rgn88~=13,
      msymbol(i i)
	mcolor(black black)
	c(l l)
	clcolor(black black)
  	sort
	legend(off)
	xlabel(-20(10)40)
	ylab(4(2)20)
	title("Panel F: 1988-92 lang. (Regions 1-12)", position(11) size(medium))
	ytitle(1988-92 lang. gain score)
	xtitle(1988 average score relative to cutoff)
	scheme(s1color)
	xline(0)
	saving(fig5f.gph,replace);
drop p90hat nonp90hat;

graph combine fig5a.gph fig5b.gph fig5c.gph fig5d.gph fig5e.gph fig5f.gph,
	iscale(*0.8)
	ysize(6)
	holes(3 6)
	scheme(s1color) 
	saving(fig5,replace);

** FIGURE 4;

clear;
use centralrole2;

preserve;
egen cas84=std(cas) if ano==84, mean(50) std(10); 
egen cas88=std(cas) if ano==88, mean(50) std(10); 
egen cas90=std(cas) if ano==90, mean(50) std(10); 
egen cas92=std(cas) if ano==92, mean(50) std(10); 

egen mat84=std(mat) if ano==84, mean(50) std(10); 
egen mat88=std(mat) if ano==88, mean(50) std(10); 
egen mat90=std(mat) if ano==90, mean(50) std(10); 
egen mat92=std(mat) if ano==92, mean(50) std(10); 

gen cas2=cas84 if ano==84;
replace cas2=cas88 if ano==88;
replace cas2=cas90 if ano==90;
replace cas2=cas92 if ano==92;

gen mat2=mat84 if ano==84;
replace mat2=mat88 if ano==88;
replace mat2=mat90 if ano==90;
replace mat2=mat92 if ano==92;

format ano %8.0g;

collapse (mean) cas2 mat2,by(ano p90);
scatter cas2 ano if p90==1,
	s(o)
	c(l)
	sort
	ylabel(37 38 39 40 41 42)
	xlabel(84 88 90 92)
	title(Panel A: P-900,position(11) size(medium))
	ytitle(Mean score)
	xtitle(Year)
	scheme(s1color)
	saving(fig4a,replace);
scatter cas2 ano if p90==0,
	s(o)
	c(l)
	sort
	ylabel(49 50 51 52 53 54)
	xlabel(84 88 90 92)
	title(Panel B: Non P-900, position(11) size(medium))
	ytitle(Mean score)
	xtitle(Year)
	scheme(s1color)
	saving(fig4b,replace);
restore;

gen cas5=cas if rule>=-5 & rule<=5;
gen cas2=cas if rule>=-2 & rule<=2;

gen mat5=mat if rule>=-5 & rule<=5;
gen mat2=mat if rule>=-2 & rule<=2;

format ano %8.0g;

preserve;
collapse (mean) cas cas5 cas2,by(ano p90);
reshape wide cas cas5 cas2,i(ano) j(p90);

gen casd=cas1-cas0;
gen cas5d=cas51-cas50;
gen cas2d=cas21-cas20;

scatter casd cas5d cas2d ano,
	msymbol(o o o)
	connect(l l l)
	sort
	ylabel(-15 -12 -9 -6 -3 0 3)
	xlabel(84 88 90 92) 
	title(Panel C: Difference (P900 - non P-900), position(11) size(medium))
	xtitle(Year)
	ytitle(Mean difference)
	legend(off)
	scheme(s1color)
	text(-11 88  "All schools", size(small) place(c))
	text(-6 88 "+/- 5 points", size(small) place(c))
	text(1 88 "+/- 2 points", size(small) place(c))
	saving(fig4c,replace);
restore;
graph combine fig4a.gph fig4b.gph fig4c.gph, scheme(s1color) saving(fig4,replace);
