
#delimit;
clear;
set mem 200m;
cd "[INSERT DATA DIRECTORY]";
use centralrole1;

** SOME RECODES;

* URBAN AND LARGER SCHOOLS INDICATORS;

generate big=1 if ncas88>=15 & rural88==0;
replace  big=0 if ncas88< 15 | rural88==1;

generate big90=1 if ncas90>=15 & rural88==0;
replace  big90=0 if ncas90< 15 | rural88==1;

generate urban88=rural88;
recode   urban88 0=1 1=0;

* 1988 AVERAGE TEST SCORES;

gen x88=(cas88+mat88)/2;
gen x882=x88*x88;
gen x883=x88*x88*x88;

* FIRST DEFINITION OF DISCONTINUITY (see text);

egen     temp1=max(x88), by(rgn88 p90);
replace  temp1=. if p90==0 | p90==.;
egen     temp2=max(temp1), by(rgn88);
generate temp3=int(temp2)+1;
rename temp3 integer;
gen rule1=x88-integer;
gen correct1=0;
replace correct1=1 if (rule1<=0 & p90==1) | (rule1>=0 & p90==0);
drop temp1 temp2;

* SECOND DEFINITION OF DISCONTINUITY (see text);

egen    temp4=pctile(x88), p(95) by(rgn88 p90);
replace temp4=. if p90==0 | p90==.;
egen    temp5=max(temp4), by(rgn88);
gen temp6=int(temp5)+1;
rename temp6 integer2;
gen rule2=x88-integer2+0.6;
gen correct2=0;
replace correct2=1 if (rule2<=0 & p90==1) | (rule2>=0 & p90==0);
drop temp4 temp5;

* RESCALE SES INDEX (INDICE DE VULNERABILIDAD);

replace indice90=100-indice90;
replace indice92=100-indice92;

* CHANGE IN SES;

gen di9290=indice92-indice90;

* GAIN SCORES;

gen dcas90=cas90-cas88;
gen dcas92=cas92-cas88;

gen dmat90=mat90-mat88;
gen dmat92=mat92-mat88;

* REGION DUMMIES;

tab rgn88, gen(R);

* SAMPLE;

egen temp=rmiss(mat88 cas88 mat90 cas90 dmat90 dcas90 p90 urban88 ncas88 ncas90 indice90);
egen temp2=rmiss(mat88 cas88 mat92 cas92 dmat92 dcas92 p90 urban88 ncas88 ncas92 indice90 indice92);

** TABLE 1;

summarize mat88 cas88 dmat90 dcas90 p90 urban88 ncas88 indice90 if temp==0;
summarize mat88 cas88 dmat90 dcas90 p90 urban88 ncas88 indice90 if temp==0 & p90==0;
summarize mat88 cas88 dmat90 dcas90 p90 urban88 ncas88 indice90 if temp==0 & p90==1;

summarize mat88 cas88 dmat92 dcas92 p90 urban88 ncas88 indice90 indice92 if temp2==0;
summarize mat88 cas88 dmat92 dcas92 p90 urban88 ncas88 indice90 indice92 if temp2==0 & p90==0;
summarize mat88 cas88 dmat92 dcas92 p90 urban88 ncas88 indice90 indice92 if temp2==0 & p90==1;

** TABLE 2;

table rgn88 if temp==0          , c(n x88 mean correct1) row;
table rgn88 if temp==0 & big==1 , c(n x88 mean correct1) row;

table rgn88 if temp==0          , c(n x88 mean correct2) row;
table rgn88 if temp==0 & big==1 , c(n x88 mean correct2) row;

** TABLE 3;

* PANEL A, 1988-1990;

reg dmat90 p90 if big==1 & temp ==0, robust;
reg dmat90 p90 rule2 if big==1 & temp ==0, robust;

program define nlmath90;
        if "`1'" == "?" {  ;                   /* if query call ... */
                global S_1 "a0 sig2_l theta";  /* parameters */
                global a0=5;                  /* initializing parameters */
                global sig2_l=30;
                global theta=0;
                exit;
        };
        replace `1'=$a0+$theta*p90+($sig2_l/($sig2_l+12.570475+725.9631/ncas88)-1)*rule2;
end;

nl math90 dmat90 if big==1 & temp==0;

reg dmat90 p90 x88 x882 x883 if big==1 & temp ==0, robust;
reg dmat90 p90 x88 x882 x883 indice90 R1-R13 if big==1 & temp ==0, robust;

* PANEL A, 1988-1992;

reg dmat92 p90 if big==1 & temp2==0, robust;
reg dmat92 p90 rule2 if big==1 & temp2==0, robust;

program define nlmath92;
        if "`1'" == "?" {  ;                   /* if query call ... */
               global S_1 "a0 sig2_l sig2_u theta";  /* parameters */
               global a0=12;              /* initializing parameters */
               global sig2_l=30;
               global sig2_u=12;
               global theta=0;
               exit;
        };
        replace `1'=$a0+$theta*p90+($sig2_l/($sig2_l+$sig2_u+893.2327/ncas88)-1)*rule2;
end;

nl math92 dmat92 if big==1 & temp2==0;

reg dmat92 p90 x88 x882 x883 if big==1 & temp2==0, robust;
reg dmat92 p90 x88 x882 x883 indice90 di9290 R1-R13 if big==1 & temp2==0, robust;

* PANEL B, 1988-1990;

reg dcas90 p90 if big==1 & temp ==0, robust;
reg dcas90 p90 rule2 if big==1 & temp ==0, robust;

program define nlcas90;
        if "`1'" == "?" {  ;                   /* if query call ... */
                global S_1 "a0 sig2_l theta";  /* parameters */
                global a0=5;                  /* initializing parameters */
                global sig2_l=30;
                global theta=0;
                exit;
        };
        replace `1'=$a0+$theta*p90+($sig2_l/($sig2_l+14.692525+586.4824/ncas88)-1)*rule2;
end;

nl cas90 dcas90 if big==1 & temp==0;

reg dcas90 p90 x88 x882 x883 if big==1 & temp ==0, robust;
reg dcas90 p90 x88 x882 x883 indice90 R1-R13 if big==1 & temp ==0, robust;

* PANEL B, 1988-1992;

reg dcas92 p90 if big==1 & temp2==0, robust;
reg dcas92 p90 rule2 if big==1 & temp2==0, robust;

program define nlcas92;
        if "`1'" == "?" {  ;                   /* if query call ... */
               global S_1 "a0 sig2_l sig2_u theta";  /* parameters */
               global a0=12;              /* initializing parameters */
               global sig2_l=30;
               global sig2_u=12;
               global theta=0;
               exit;
        };
        replace `1'=$a0+$theta*p90+($sig2_l/($sig2_l+$sig2_u+658.6048/ncas88)-1)*rule2;
end;

nl cas92 dcas92 if big==1 & temp2==0;

reg dcas92 p90 x88 x882 x883 if big==1 & temp2==0, robust;
reg dcas92 p90 x88 x882 x883 indice90 di9290 R1-R13 if big==1 & temp2==0, robust;

** TABLE 4;

* PANEL A;

reg dmat92 p90 if big==1 & rule2>=-5 & rule2<=5 & temp2==0, robust;
reg dmat92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-5 & rule2<=5 & temp2==0, robust;

reg dmat92 p90 if big==1 & rule2>=-3 & rule2<=3 & temp2==0, robust;
reg dmat92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-3 & rule2<=3 & temp2==0, robust;

reg dmat92 p90 if big==1 & rule2>=-2 & rule2<=2 & temp2==0, robust;
reg dmat92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-2 & rule2<=2 & temp2==0, robust;

* PANEL B;

reg dcas92 p90 if big==1 & rule2>=-5 & rule2<=5 & temp2==0, robust;
reg dcas92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-5 & rule2<=5 & temp2==0, robust;

reg dcas92 p90 if big==1 & rule2>=-3 & rule2<=3 & temp2==0, robust;
reg dcas92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-3 & rule2<=3 & temp2==0, robust;

reg dcas92 p90 if big==1 & rule2>=-2 & rule2<=2 & temp2==0, robust;
reg dcas92 p90 x88 x882 x883 indice90 di9290 if big==1 & rule2>=-2 & rule2<=2 & temp2==0, robust;

** TABLE 5;

gen ivrule2=0 if rule2>0 & rule2<100;
replace ivrule2=1 if rule2>-100 & rule2<=0;

* PANEL A;

reg p90 ivrule2                               if big==1 & temp2==0                                     , robust;
reg p90 ivrule2 rule2                         if big==1 & temp2==0                                     , robust;
reg p90 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0                                     , robust;
reg p90 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5)            , robust;
reg p90 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 &                          rgn88~=13, robust;
reg p90 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5) & rgn88~=13, robust;

* PANEL B;

reg dmat92 ivrule2                               if big==1 & temp2==0                                     , robust;
reg dmat92 ivrule2 rule2                         if big==1 & temp2==0                                     , robust;
reg dmat92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0                                     , robust;
reg dmat92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5)            , robust;
reg dmat92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 &                          rgn88~=13, robust;
reg dmat92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5) & rgn88~=13, robust;

* PANEL C;

reg dcas92 ivrule2                               if big==1 & temp2==0                                     , robust;
reg dcas92 ivrule2 rule2                         if big==1 & temp2==0                                     , robust;
reg dcas92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0                                     , robust;
reg dcas92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5)            , robust;
reg dcas92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 &                          rgn88~=13, robust;
reg dcas92 ivrule2 x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5) & rgn88~=13, robust;

* PANEL D;

ivreg dmat92 (p90=ivrule2)                               if big==1 & temp2==0                                     , robust;
ivreg dmat92 (p90=ivrule2) rule2                         if big==1 & temp2==0                                     , robust;
ivreg dmat92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0                                     , robust;
ivreg dmat92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5)            , robust;
ivreg dmat92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 &                          rgn88~=13, robust;
ivreg dmat92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5) & rgn88~=13, robust;

* PANEL E;

ivreg dcas92 (p90=ivrule2)                               if big==1 & temp2==0                                     , robust;
ivreg dcas92 (p90=ivrule2) rule2                         if big==1 & temp2==0                                     , robust;
ivreg dcas92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0                                     , robust;
ivreg dcas92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5)            , robust;
ivreg dcas92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 &                          rgn88~=13, robust;
ivreg dcas92 (p90=ivrule2) x88 x882 x883 indice90 di9290 if big==1 & temp2==0 & (rule2>=-5 & rule2<=5) & rgn88~=13, robust;

